% example.m
%
% This example script allows the user to inport data from a recorded gpx
% file, a measurement from a txt file. The gps data coordinates are
% converted into certesian xy points and correlated with the measurements
% via their timestamps
%
% Author: Ricardo M.R. Ado,
% Ultrafast Bio- and Nanophotonics group,
% INL - International Iberian Nanotechnology Laboratory, Portugal
% 
% Software eveloped in frame of the Interreg NanoEATERS - Cdu#1 NanoLED
% project, with funding grant number 0181_NANOEATERS_1_EP
%
gpx = importGPX();                 % open "example.gpx"
pos = convertGPXtoXY(gpx, true);   % center at initial point
sensor = importSensor('temp');     % open "temp.txt"
dt = 1000;                          % 1 s time resolution
pingMax = 40000;                    % maximum ping limited to 40 s
[sensor, pos] = correlateSensorPos(sensor, pos ,dt ,pingMax);
xPx = -350:1:350;                   % x array of output map
yPx = -250:1:450;                   % y array of output map
integrateNtimes = 160;              % number of integration iterations
center = [-13.06, 91.72];           % specified center
maxDist = 345;                      % maximum distance
[X,Y,Z, ZAvg ] = mapSpreadLine(pos, sensor.pingInt, xPx, yPx,...
                                integrateNtimes,center , maxDist);

% represent the results
figure('color','w')
imagesc(xPx,yPx,ZAvg/1000)
xlabel('x (m)'); ylabel('y (m)')
c = colorbar();
ylabel(c,'Response Time (s)')
axis image xy