function gpx = importGPX()
    % gpx = importGPX()
    %
    % Import recorded GPS coordinates from a *.gpx file.
    % The user is prompted to select a file
    % inputs:
	%   none
    % outputs:
    %   gps = matrix containing the imported GPS coordinates
    %
    % Author: Ricardo M.R. Ado,
    % Ultrafast Bio- and Nanophotonics group,
    % INL - International Iberian Nanotechnology Laboratory, Portugal
    % 
    % Software eveloped in frame of the Interreg NanoEATERS - Cdu#1 NanoLED
    % project, with funding grant number 0181_NANOEATERS_1_EP
    %
    % 
    
    head = 24; % number of header rows
    maxLength = 10000; % maximum number of lines in gpx file
    
    gpx = [];
    
    % prompt the user to select a file
    [filename, pathname] = uigetfile('*.gpx');
    if ~isempty(filename)
        fileID = fopen([pathname '\' filename]);
        for i = 1 :head % ignore the heather
            tline = fgets(fileID);
        end
        i = 0;
        
        while (i < maxLength) && ~isempty(tline)
            try
                data = sscanf(fgets(fileID),' <trkpt lat="%f" lon="%f">');
                gpx(end+1,[1 2]) = data; % lat and lon
                data = sscanf(fgets(fileID),' <ele>%f</ele>');
                gpx(end,3) = data; % ele
                data = sscanf(fgets(fileID),' <time>%d-%d-%dT%d:%d:%fZ</time>');
                gpx(end,4:9) = data;
                for i = 1:4
                    fgets(fileID);
                    % <extensions>
                    % <geotracker:meta c="2.02" s="0.01" />
                    % </extensions>
                    % </trkpt>
                end
            catch
                tline = [];
            end
            i = i + 7;
        end
    end
    fclose(fileID);
end